MaterializedIndexError

Enum MaterializedIndexError 

pub enum MaterializedIndexError {
Show 23 variants Database(DatabaseError), Transaction(TransactionError), Table(TableError), Storage(StorageError), Commit(CommitError), Durability(SetDurabilityError), Mutation(MutationError), MalformedCheckpoint, Diverged { sequence: u64, }, IdempotencyDiverged { transaction_id: Uuid, }, MalformedIdempotencyKey, Vector(VectorValueError), UnknownVectorSpace { name: String, }, VectorSpaceConflict { name: String, }, MalformedVectorIndex, Lexical(LexicalError), LexicalIndexConflict { name: String, }, UnknownLexicalIndex { name: String, }, MalformedLexicalIndex, MalformedLexicalProjection, Document(DocumentError), VectorCandidateBudgetExceeded { maximum: u64, }, VectorByteBudgetExceeded { maximum: u64, },
}
Failure while opening, verifying, or updating the rebuildable redb index.

Variants



Database(DatabaseError)

redb could not open or create its database file.



Transaction(TransactionError)

redb could not begin a transaction.



Table(TableError)

A redb table could not be opened.



Storage(StorageError)

A redb table read or write failed.



Commit(CommitError)

A redb transaction could not be committed.



Durability(SetDurabilityError)

A redb durability mode could not be selected.



Mutation(MutationError)

A committed operation is not a valid canonical mutation.



MalformedCheckpoint

Stored index metadata has an invalid length or combination.



Diverged

The index checkpoint does not identify a commit in the verified log.

Fields

sequence: u64

Checkpoint sequence that could not be verified.



IdempotencyDiverged

A persisted idempotency receipt is malformed or conflicts with the log.

Fields

transaction_id: Uuid

Transaction identifier with conflicting durable identity.



MalformedIdempotencyKey

A persisted idempotency key is not a UUID.



Vector(VectorValueError)

A canonical shared vector value is invalid.



UnknownVectorSpace

A vector mutation refers to a space that has not been defined.

Fields

name: String

Canonical vector-space name.



VectorSpaceConflict

An existing immutable vector-space definition differs.

Fields

name: String

Canonical vector-space name.



MalformedVectorIndex

Persisted vector-index bytes are not canonical.



Lexical(LexicalError)

A canonical lexical definition is invalid.



LexicalIndexConflict

An existing immutable lexical-index definition differs.

Fields

name: String

Canonical lexical-index name.



UnknownLexicalIndex

A lexical retrieval refers to an index that has not been defined.

Fields

name: String

Canonical lexical-index name.



MalformedLexicalIndex

Persisted lexical-index bytes are not canonical.



MalformedLexicalProjection

Persisted lexical postings/statistics are not canonical.



Document(DocumentError)

A structured document cannot be decoded while maintaining a lexical projection.



VectorCandidateBudgetExceeded

Reading candidates exceeded the caller’s count budget.

Fields

maximum: u64

Maximum candidates permitted.



VectorByteBudgetExceeded

Reading candidates exceeded the caller’s logical key/vector byte budget.

Fields

maximum: u64

Maximum encoded key and vector bytes permitted.