pub enum Mutation {
Put {
key: Vec<u8>,
value: Vec<u8>,
},
Delete {
key: Vec<u8>,
},
}Expand description
A deterministic mutation persisted inside one transaction operation frame.
Variants
Put
Replaces the value stored under a nonempty binary key.
Delete
Removes a binary key. Deleting a missing key is idempotent.
Implementations