pub struct RecoveryReport {
pub base_sequence: u64,
pub base_digest: [u8; 32],
pub transactions: Vec<RecoveredTransaction>,
pub ignored_uncommitted_transactions: u64,
pub duplicate_commits: u64,
pub truncated_tail_bytes: u64,
pub valid_bytes: u64,
pub last_sequence: u64,
pub last_digest: [u8; 32],
}Expand description
Evidence produced while opening and validating a segment.
Fields
base_sequence: u64Sequence immediately preceding this segment, or zero for the first segment.
base_digest: [u8; 32]Digest immediately preceding this segment, or all zero for the first segment.
transactions: Vec<RecoveredTransaction>Unique committed transactions in commit order.
ignored_uncommitted_transactions: u64Complete but uncommitted transaction attempts ignored during recovery.
duplicate_commits: u64Repeated commits with the same id and content, deduplicated during replay.
truncated_tail_bytes: u64Incomplete bytes removed from the physical tail.
valid_bytes: u64Length after any incomplete tail was removed.
last_sequence: u64Last complete frame sequence, including uncommitted attempts.
last_digest: [u8; 32]Digest of the last complete frame.