pub struct SnapshotReadLimits {
pub file_bytes: u64,
pub entries: u64,
pub decoded_bytes: u64,
}Expand description
Resource limits for loading a verified logical snapshot as an offline witness.
Fields
file_bytes: u64Maximum complete snapshot file length.
entries: u64Maximum number of logical KV entries.
decoded_bytes: u64Maximum aggregate decoded key and value bytes retained in memory.