MaterializedIndexError

Enum MaterializedIndexError 

pub enum MaterializedIndexError {
    Database(DatabaseError),
    Transaction(TransactionError),
    Table(TableError),
    Storage(StorageError),
    Commit(CommitError),
    Durability(SetDurabilityError),
    Mutation(MutationError),
    MalformedCheckpoint,
    Diverged {
        sequence: u64,
    },
    IdempotencyDiverged {
        transaction_id: Uuid,
    },
    MalformedIdempotencyKey,
}
Failure while opening, verifying, or updating the rebuildable redb index.

Variants



Database(DatabaseError)

redb could not open or create its database file.



Transaction(TransactionError)

redb could not begin a transaction.



Table(TableError)

A redb table could not be opened.



Storage(StorageError)

A redb table read or write failed.



Commit(CommitError)

A redb transaction could not be committed.



Durability(SetDurabilityError)

A redb durability mode could not be selected.



Mutation(MutationError)

A committed operation is not a valid canonical mutation.



MalformedCheckpoint

Stored index metadata has an invalid length or combination.



Diverged

The index checkpoint does not identify a commit in the verified log.

Fields

sequence: u64

Checkpoint sequence that could not be verified.



IdempotencyDiverged

A persisted idempotency receipt is malformed or conflicts with the log.

Fields

transaction_id: Uuid

Transaction identifier with conflicting durable identity.



MalformedIdempotencyKey

A persisted idempotency key is not a UUID.